@@ -86,7 +86,7 @@
 #define KGLOBALACCEL_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KGLOBALACCEL_NO_DEPRECATED
-#  define KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54d00
+#  define KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KGLOBALACCEL_NO_DEPRECATED_WARNINGS
 #  define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0x54d00
+#    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -131,5 +131,12 @@
 #define KGLOBALACCEL_DEPRECATED_VERSION_5(minor, text)      KGLOBALACCEL_DEPRECATED_VERSION_5_##minor(text)
 #define KGLOBALACCEL_DEPRECATED_VERSION(major, minor, text) KGLOBALACCEL_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KGLOBALACCEL_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KGLOBALACCEL_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KGLOBALACCEL_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KGLOBALACCEL_DEPRECATED_VERSION(major, minor, text)
+#  define KGLOBALACCEL_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KGLOBALACCEL_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KGLOBALACCEL_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KGLOBALACCEL_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KGLOBALACCEL_EXPORT_H */
